@@ -46,15 +46,19 @@ def BrowserGCM(headless=True):
             chrome_options.add_argument("--no-sandbox")
 
         # import pudb;pu.db
-        # display = Display(visible=0, size=(800, 600))
-        # display.start()
+        try:
+            display = Display(visible=0, size=(800, 600))
+            display.start()
+        except Exception as e:
+            print(f'Failed loading virtual display {e}')
+            raise BrowserException(e)
 
         return webdriver.Chrome(options=chrome_options)
     try:
         _browser = init_browser(headless)
         yield _browser
     except Exception as exc:
-        print(exc)
+        print(f'Failed init browser ?? {exc}')
         raise BrowserException(exc)
     finally:
         _browser.quit()
